__all__ = [
    'names',
    'WEBDRIVER',
    'TIMEZONESAFECONTROL',
    'CutJunkCharactersFromDocumentText',
    'FilterOnlyNewDocumentWithDB',
    'SaveDocumentToDB',
]

WEBDRIVER: str = 'WebDriver'
TIMEZONESAFECONTROL: str = 'TimezoneSafeControl'
CutJunkCharactersFromDocumentText: str = 'CutJunkCharactersFromDocumentText'
FilterOnlyNewDocumentWithDB: str = 'FilterOnlyNewDocumentWithDB'
SaveDocumentToDB: str = 'SaveDocumentToDB'

names = (
    WEBDRIVER,
    TIMEZONESAFECONTROL,
    CutJunkCharactersFromDocumentText,
    FilterOnlyNewDocumentWithDB,
    SaveDocumentToDB,
)
